import importlib
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    import psutil  # noqa: F401


class PsutilWrapper():
    """Wrap a copy of psutil."""

    def __init__(self) -> None:
        psutil_spec = importlib.util.find_spec("psutil")
        assert psutil_spec and psutil_spec.loader
        psutil_module = importlib.util.module_from_spec(psutil_spec)
        psutil_spec.loader.exec_module(psutil_module)
        self.psutil: psutil = psutil_module



import psutil
import psutil_home_assistant

def test_multiple_copies():
    """Test that multiple psutil instances can be created and do not interfere."""

    psutil1 = psutil_home_assistant.PsutilWrapper()
    psutil2 = psutil_home_assistant.PsutilWrapper()

    assert psutil._last_cpu_times is not psutil1.psutil._last_cpu_times
    assert psutil1.psutil._last_cpu_times is not psutil2.psutil._last_cpu_times



"""Setup for aiohue."""
from setuptools import find_packages, setup

LONG_DESC = open("README.md").read()
PACKAGES = find_packages(exclude=["tests", "tests.*"])
REQUIREMENTS = list(val.strip() for val in open("requirements.txt"))
MIN_PY_VERSION = "3.8"

setup(
    name="psutil-home-assistant",
    version="0.0.1",
    license="Apache License 2.0",
    url="https://github.com/home-assistant-libs/psutil-home-assistant",
    author="Erik Montnemery",
    description="Wrapper for psutil to allow it to be used several times in the same process.",
    long_description=LONG_DESC,
    long_description_content_type="text/markdown",
    packages=PACKAGES,
    zip_safe=True,
    platforms="any",
    install_requires=REQUIREMENTS,
    python_requires=f">={MIN_PY_VERSION}",
    classifiers=[
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
